==> kapla-2.1.2.tgz: package/lib/core/Scope.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

import { Data } from './Data';
export var Scope =
/*#__PURE__*/
function () {
  function Scope(schema, slug, element, props) {
    _classCallCheck(this, Scope);

    this.schema = schema;
    this.slug = slug;
    this.element = element;
    this.props = props;
    this.data = new Data(this);
  }

  _createClass(Scope, [{
    key: "getRefs",
    value: function getRefs() {
      var refs = {};
      var elements = this.element.querySelectorAll(this.refSelector);

      var _arr = Array.from(elements);

      for (var _i = 0; _i < _arr.length; _i++) {
        var element = _arr[_i];
        var name = this.getRefName(element);

        if (refs[name]) {
          if (Array.isArray(refs[name])) {
            refs[name].push(element);
          } else {
            refs[name] = [refs[name], element];
          }
        } else {
          refs[name] = element;
        }
      }

      return refs;
    }
  }, {
    key: "getRefName",
    value: function getRefName(element) {
      var _this = this;

      return element.getAttribute(this.refAttribute).split(' ').find(function (ref) {
        return ref.match("".concat(_this.slug, "."));
      }).replace("".concat(this.slug, "."), '');
    }
  }, {
    key: "refs",
    get: function get() {
      return this.getRefs();
    }
  }, {
    key: "refAttribute",
    get: function get() {
      return this.schema.refAttribute;
    }
  }, {
    key: "refSelector",
    get: function get() {
      return "[".concat(this.refAttribute, "*='").concat(this.slug, ".']");
    }
  }]);

  return Scope;
}();

==> kapla-2.1.4.tgz: package/lib/core/Scope.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

import { Data } from './Data';
export var Scope =
/*#__PURE__*/
function () {
  function Scope(schema, slug, element, props) {
    _classCallCheck(this, Scope);

    this.schema = schema;
    this.slug = slug;
    this.element = element;
    this.props = props;
    this.data = new Data(this);
  }

  _createClass(Scope, [{
    key: "getRefs",
    value: function getRefs() {
      var refs = {};
      var elements = this.element.querySelectorAll(this.refSelector);

      for (var _i = 0, _Array$from = Array.from(elements); _i < _Array$from.length; _i++) {
        var element = _Array$from[_i];
        var name = this.getRefName(element);

        if (refs[name]) {
          if (Array.isArray(refs[name])) {
            refs[name].push(element);
          } else {
            refs[name] = [refs[name], element];
          }
        } else {
          refs[name] = element;
        }
      }

      return refs;
    }
  }, {
    key: "getRefName",
    value: function getRefName(element) {
      var _this = this;

      return element.getAttribute(this.refAttribute).split(' ').find(function (ref) {
        return ref.match("".concat(_this.slug, "."));
      }).replace("".concat(this.slug, "."), '');
    }
  }, {
    key: "refs",
    get: function get() {
      return this.getRefs();
    }
  }, {
    key: "refAttribute",
    get: function get() {
      return this.schema.refAttribute;
    }
  }, {
    key: "refSelector",
    get: function get() {
      return "[".concat(this.refAttribute, "*='").concat(this.slug, ".']");
    }
  }]);

  return Scope;
}();
